<?php

namespace ElementHelper\Widget;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
use \Elementor\Core\Schemes\Typography;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;

defined( 'ABSPATH' ) || die();

class Tx_Headers extends Element_El_Widget {

    /**
     * Get widget name.
     *
     * Retrieve Future Core widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'tx_headers';
    }

    /**
     * Get widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title() {
        return __( 'TX Headers', 'future-core' );
    }

    public function get_custom_help_url() {
        return 'http://elementor.themexriver.com/widgets/gradient-heading/';
    }

    /**
     * Get widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'elh-widget-icon eicon-t-letter';
    }

    public function get_keywords() {
        return ['btn', 'header', 'future', 'future header'];
    }

    // get menu by slug
    public function get_menu() {
        $menus = wp_get_nav_menus();
        $menu_list = array();
        if ( $menus ) {
            foreach ( $menus as $menu ) {
                $menu_list[ $menu->slug ] = $menu->name;
            }
        }
        return $menu_list;
    }

    protected function register_content_controls() {

        //Settings
        $this->start_controls_section(
            '_section_design_settings',
            [
                'label' => __( 'DESIGN STYLE', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'design_style',
            [
                'label'              => __( 'Design Style', 'future-core' ),
                'type'               => Controls_Manager::SELECT,
                'options'            => [
                    'style_1' => __( 'Header One', 'future-core' ),
                    'style_2' => __( 'Header two', 'future-core' ),
                ],
                'default'            => 'style_1',
                'frontend_available' => true,
                'style_transfer'     => true,
            ]
        );

        $this->end_controls_section();

        // logo section
        $this->start_controls_section(
            '_section_logo',
            [
                'label' => __( 'Logo', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // enable logo shape
        $this->add_control(
            'enable_logo_shape',
            [
                'label'        => __( 'Enable Logo Shape', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'description'  => __( 'Enable logo shape only for style 1', 'future-core' ),
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
                'condition'    => [
                    'design_style' => [
                        'style_1',
                    ],
                ],
            ]
        );

        // before logo shape iamge
        $this->add_control(
            'before_logo_shape_image',
            [
                'label'       => __( 'Before Logo Shape Image', 'future-core' ),
                'type'        => Controls_Manager::MEDIA,
                'default'     => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
                'condition'   => [
                    'design_style' => [
                        'style_1',
                    ],
                    'enable_logo_shape' => 'yes',
                ],
            ]
        );

        // logo
        $this->add_control(
            'logo',
            [
                'label'       => __( 'Logo', 'future-core' ),
                'type'        => Controls_Manager::MEDIA,
                'default'     => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
            ]
        );

        // enable mobile logo
        $this->add_control(
            'enable_mobile_logo',
            [
                'label'        => __( 'Enable Mobile Logo', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'description'  => __( 'Enable mobile logo only for mobile device', 'future-core' ),
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'no',
            ]
        );

        // sideino logo
        $this->add_control(
            'mobile_logo',
            [
                'label'       => __( 'Mobile Logo', 'future-core' ),
                'type'        => Controls_Manager::MEDIA,
                'default'     => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'label_block' => true,
                'condition'   => [
                    'enable_mobile_logo' => 'yes',
                ],
            ]
        );

        // enable custom link
        $this->add_control(
            'enable_custom_link',
            [
                'label'        => __( 'Enable Custom Link', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'no',
            ]
        );

        // custom link
        $this->add_control(
            'custom_link',
            [
                'label'       => __( 'Custom Link', 'future-core' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => __( 'https://your-link.com', 'future-core' ),
                'show_label'  => false,
                'default'     => [
                    'url' => '#',
                ],
                'condition'   => [
                    'enable_custom_link' => 'yes',
                ],
            ]
        );

        // end logo section
        $this->end_controls_section();

        $this->start_controls_section(
            '_section_menu',
            [
                'label' => __( 'Menu Options', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // select menu
        $this->add_control(
            'select_menu',
            [
                'label'       => __( 'Select Menu', 'future-core' ),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_menu(),
                'label_block' => true,
                'multiple'    => false,
            ]
        );

        $this->end_controls_section();

        // CONTACT NUMBER
        $this->start_controls_section(
            '_section_contact_number',
            [
                'label' => __( 'Contact Number', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // enable icon
        $this->add_control(
            'enable_icon',
            [
                'label'        => __( 'Enable Icon', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        // contact info icon
        $this->add_control(
            'contact_info_icon',
            [
                'label'       => __( 'Contact Info Icon', 'future-core' ),
                'type'        => Controls_Manager::ICONS,
                'default'     => [
                    'value'   => 'fal fa-phone',
                    'library' => 'solid',
                ],
                'label_block' => true,
                'condition'   => [
                    'enable_icon' => 'yes',
                ],
            ]
        );

        // contact info text
        $this->add_control(
            'contact_info_text',
            [
                'label'       => __( 'Contact Info Text', 'future-core' ),
                'type'        => Controls_Manager::WYSIWYG,
                'default'     => __( 'Call Us Now', 'future-core' ),
                'label_block' => true,
            ]
        );

        // END CONTACT NUMBER
        $this->end_controls_section();

        // settings section
        $this->start_controls_section(
            '_section_settings',
            [
                'label' => __( 'SETTINGS', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // enable sticky header
        $this->add_control(
            'enable_sticky_header',
            [
                'label'        => __( 'ENABLE STICKY HEADER', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        // ENABLE CART ICON
        $this->add_control(
            'enable_cart_icon',
            [
                'label'        => __( 'ENABLE CART ICON?', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

         // ENABLE CONTACT INFO
         $this->add_control(
            'enable_contact_info',
            [
                'label'        => __( 'ENABLE CONTACT INFO?', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        // end settings section
        $this->end_controls_section();

    }

    protected function register_style_controls() {

        // HEADER STYLE
        $this->start_controls_section(
            '_section_style_header',
            [
                'label' => __( 'Header', 'future-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        // ENABLE POSITION ABSOLUTE
        $this->add_control(
            'enable_position_absolute',
            [
                'label'        => __( 'Enable Position Absolute', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
            ]
        );

        // HEADER TOP POSITION
        $this->add_responsive_control(
            'header_top_position',
            [
                'label'     => __( 'Header Top Position', 'future-core' ),
                'type'      => Controls_Manager::SLIDER,
                'size_units'=> [ 'px', '%' ],
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .tx-header' => 'top: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'enable_position_absolute' => 'yes',
                ],
            ]
        );

        // END HEADER STYLE
        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $dir = dirname( __FILE__ );

        $style = !empty($settings['design_style']) ? $settings['design_style'] : 'style_1';

        switch ($style) {
            case 'style_3':
                include $dir . '/views/view-3.php';
                break;
            case 'style_2':
                include $dir . '/views/view-2.php';
                break;
            default:
                include $dir . '/views/view-1.php';
        }
    }
}
