<?php

namespace ElementHelper\Widget;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
use \Elementor\Core\Schemes\Typography;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;

defined( 'ABSPATH' ) || die();

class Tx_Hero_Slider extends Element_El_Widget {

    /**
     * Get widget name.
     *
     * Retrieve Element Helper widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'tx_hero_slider';
    }

    /**
     * Get widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title() {
        return __( 'TX Hero Slide', 'future-core' );
    }

    public function get_custom_help_url() {
        return 'http://elementor.themexriver.com/widgets/gradient-heading/';
    }

    /**
     * Get widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'elh-widget-icon eicon-t-letter';
    }

    public function get_keywords() {
        return ['future', 'slide'];
    }

    protected function register_content_controls() {

        //Settings
        $this->start_controls_section(
            '_section_design_settings',
            [
                'label' => __( 'Choos Design', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'design_style',
            [
                'label'              => __( 'Design Style', 'future-core' ),
                'type'               => Controls_Manager::SELECT,
                'options'            => [
                    'style_1' => __( 'Style 1', 'future-core' ),
                ],
                'default'            => 'style_1',
                'frontend_available' => true,
                'style_transfer'     => true,
            ]
        );

        $this->end_controls_section();

        // SHAPE IMAGES
        $this->start_controls_section(
            '_section_shape_images',
            [
                'label' => __( 'Shape Images', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // SHAPE IMAGE 1
        $this->add_control(
            'shape_image_1',
            [
                'label'   => __( 'Shape Image 1', 'future-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        // SHAPE IMAGE 2
        $this->add_control(
            'shape_image_2',
            [
                'label'   => __( 'Shape Image 2', 'future-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        // SHAPE IMAGE 3
        $this->add_control(
            'shape_image_3',
            [
                'label'   => __( 'Shape Image 3', 'future-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        // SHAPE IMAGE 4
        $this->add_control(
            'shape_image_4',
            [
                'label'   => __( 'Shape Image 4', 'future-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        // SHAPE IMAGE 5
        $this->add_control(
            'shape_image_5',
            [
                'label'   => __( 'Shape Image 5', 'future-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        // SHAPE IMAGE 6
        $this->add_control(
            'shape_image_6',
            [
                'label'   => __( 'Shape Image 6', 'future-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        // END
        $this->end_controls_section();

        // SLIDE ITEMS
        $this->start_controls_section(
            '_section_slide_items',
            [
                'label' => __( 'Slide Items', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        // SLIDE IMAGE
        $repeater->add_control(
            'slide_image',
            [
                'label'   => __( 'Slide Image', 'future-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'slides',
            [
                'label'       => __( 'Slides', 'future-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
            ]
        );

        $this->end_controls_section();

        // TEXT & DESCRIPTION
        $this->start_controls_section(
            '_section_text_description',
            [
                'label' => __( 'Text & Description', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // TITLE 1
        $this->add_control(
            'title',
            [
                'label'       => __( 'Title 1', 'future-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'default'     => __( 'generative', 'future-core' ),
                'placeholder' => __( 'Type your title here', 'future-core' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title_tag',
            [
                'label'     => __( 'Title HTML Tag', 'future-core' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'h1' => [
                        'title' => __( 'H1', 'future-core' ),
                        'icon'  => 'eicon-editor-h1',
                    ],
                    'h2' => [
                        'title' => __( 'H2', 'future-core' ),
                        'icon'  => 'eicon-editor-h2',
                    ],
                    'h3' => [
                        'title' => __( 'H3', 'future-core' ),
                        'icon'  => 'eicon-editor-h3',
                    ],
                    'h4' => [
                        'title' => __( 'H4', 'future-core' ),
                        'icon'  => 'eicon-editor-h4',
                    ],
                    'h5' => [
                        'title' => __( 'H5', 'future-core' ),
                        'icon'  => 'eicon-editor-h5',
                    ],
                    'h6' => [
                        'title' => __( 'H6', 'future-core' ),
                        'icon'  => 'eicon-editor-h6',
                    ],
                ],
                'default'   => 'h2',
                'toggle'    => false,
            ]
        );

        // DESCRIPTION
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description', 'future-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'default'     => __( 'Jitter enables us to focus more on content rather than editing motion. And it definitely makes our workflow smoother thanks to the Figma plugin.', 'future-core' ),
                'placeholder' => __( 'Type your description here', 'future-core' ),
            ]
        );

        // END
        $this->end_controls_section();

        // VIDEO BOX
        $this->start_controls_section(
            '_section_video_box',
            [
                'label' => __( 'Video Box', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // VIDEO BG IMAGE
        $this->add_control(
            'video_bg_image',
            [
                'label'   => __( 'Video BG Image', 'future-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        // VIDEO IMAGE
        $this->add_control(
            'video_image',
            [
                'label'   => __( 'Video Image', 'future-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        // VIDEO LINK
        $this->add_control(
            'video_link_url',
            [
                'label'       => __( 'Video Link URL', 'future-core' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => __( 'https://your-link.com', 'future-core' ),
                'default'     => [
                    'url' => 'https://www.youtube.com/watch?v=kxPCFljwJws',
                ],
            ]
        );

        // video title
        $this->add_control(
            'video_title',
            [
                'label'       => __( 'Video Title', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Watch Video', 'future-core' ),
                'placeholder' => __( 'Type your video title here', 'future-core' ),
                'label_block' => true,
            ]
        );

        // END
        $this->end_controls_section();

        // FEATE LISTS
        $this->start_controls_section(
            '_section_feature_lists',
            [
                'label' => __( 'Feature Lists', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        // ENABLE ICON
        $repeater->add_control(
            'enable_icon',
            [
                'label'        => __( 'Enable Icon', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        // ICONS
        $repeater->add_control(
            'feature_icon',
            [
                'label'       => __( 'Icon', 'future-core' ),
                'type'        => Controls_Manager::ICONS,
                'default'     => [
                    'value'   => 'fas fa-check',
                    'library' => 'solid',
                ],
                'label_block' => true,
                'condition'   => [
                    'enable_icon' => 'yes',
                ],
            ]
        );

        // TITLE
        $repeater->add_control(
            'feature_title',
            [
                'label'       => __( 'Title', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Feature Title', 'future-core' ),
                'placeholder' => __( 'Type your title here', 'future-core' ),
                'label_block' => true,
            ]
        );

        // FEATURE LISTS
        $this->add_control(
            'feature_lists',
            [
                'label'       => __( 'Feature Lists', 'future-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'feature_title' => __( 'Feature Title #1', 'future-core' ),
                    ],
                    [
                        'feature_title' => __( 'Feature Title #2', 'future-core' ),
                    ],
                    [
                        'feature_title' => __( 'Feature Title #3', 'future-core' ),
                    ],
                ],
                'title_field' => '{{{ feature_title }}}',
            ]
        );

        // END
        $this->end_controls_section();

        // IMAGE SEARCH SECTION
        $this->start_controls_section(
            '_section_image_search',
            [
                'label' => __( 'Image Search', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // ICON
        $this->add_control(
            'image_search_icon',
            [
                'label'       => __( 'Icon', 'future-core' ),
                'type'        => Controls_Manager::ICONS,
                'default'     => [
                    'value'   => 'fas fa-search',
                    'library' => 'solid',
                ],
                'label_block' => true,
            ]
        );

        // TITLE
        $this->add_control(
            'image_search_title',
            [
                'label'       => __( 'Title', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Image Search', 'future-core' ),
                'placeholder' => __( 'Type your title here', 'future-core' ),
            ]
        );

        // search placeholder
        $this->add_control(
            'image_search_placeholder',
            [
                'label'       => __( 'Search Placeholder', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Describe What you want or Hit a tag Below', 'future-core' ),
                'placeholder' => __( 'Type your search placeholder here', 'future-core' ),
            ]
        );

        // RIGHT IMAGE
        $this->add_control(
            'image_search_right_image',
            [
                'label'   => __( 'Right Image', 'future-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        // REPEATER
        $repeater = new \Elementor\Repeater();

        // TAG NAME
        $repeater->add_control(
            'tag_name',
            [
                'label'       => __( 'Tag Name', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Tag Name', 'future-core' ),
                'placeholder' => __( 'Type your tag name here', 'future-core' ),
            ]
        );

        // LIST
        $this->add_control(
            'image_search_lists',
            [
                'label'       => __( 'Image Search Lists', 'future-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'tag_name' => __( 'Tag Name #1', 'future-core' ),
                    ],
                ],
                'title_field' => '{{{ tag_name }}}',
            ]
        );

        // END
        $this->end_controls_section();

        // COUNT BOX
        $this->start_controls_section(
            '_section_count_box',
            [
                'label' => __( 'Count Box', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // repater
        $repeater = new \Elementor\Repeater();

        // COUNT NUMBER
        $repeater->add_control(
            'count_number',
            [
                'label'       => __( 'Count Number', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( '100', 'future-core' ),
                'placeholder' => __( 'Type your count number here', 'future-core' ),
            ]
        );

        // COUNT SIGN
        $repeater->add_control(
            'count_sign',
            [
                'label'       => __( 'Count Sign', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'K', 'future-core' ),
                'placeholder' => __( 'Type your count sign here', 'future-core' ),
            ]
        );

        // TITLE
        $repeater->add_control(
            'count_title',
            [
                'label'       => __( 'Count Title', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Happy Clients', 'future-core' ),
                'placeholder' => __( 'Type your count title here', 'future-core' ),
            ]
        );

        // COUNT BOX
        $this->add_control(
            'count_boxes',
            [
                'label'       => __( 'Count Boxes', 'future-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'count_number' => __( '100', 'future-core' ),
                        'count_sign'   => __( 'K', 'future-core' ),
                        'count_title'  => __( 'Happy Clients', 'future-core' ),
                    ],
                ],
                'title_field' => '{{{ count_title }}}',
            ]
        );

        // END
        $this->end_controls_section();

        // SETTINGS
        $this->start_controls_section(
            '_section_settings',
            [
                'label' => __( 'Settings', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // ENABLE SLIDER PAGINATION
        $this->add_control(
            'enable_slider_pagination',
            [
                'label'        => __( 'Enable Slider Pagination', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        // ENABLE SLIDER NAVIGATION
        $this->add_control(
            'enable_slider_navigation',
            [
                'label'        => __( 'Enable Slider Navigation', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        // ENABLE SEARCH BOX
        $this->add_control(
            'enable_search_box',
            [
                'label'        => __( 'Enable Search Box', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        // ENABLE TAGS
        $this->add_control(
            'enable_tags',
            [
                'label'        => __( 'Enable Tags', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        // ENABLE COUNT BOX
        $this->add_control(
            'enable_count_box',
            [
                'label'        => __( 'Enable Count Box', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        // ENABLE VIDEO BOX
        $this->add_control(
            'enable_video_box',
            [
                'label'        => __( 'Enable Video Box', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        // enable_feature_list
        $this->add_control(
            'enable_feature_list',
            [
                'label'        => __( 'Enable Feature List', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Yes', 'future-core' ),
                'label_off'    => __( 'No', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        // END
        $this->end_controls_section();

    }

    protected function register_style_controls() {


    }

    protected function render() {

        $settings = $this->get_settings_for_display();
        $dir = dirname( __FILE__ );

        $style = !empty($settings['design_style']) ? $settings['design_style'] : 'style_1';

        switch ($style) {
            case 'style_2':
                include $dir . '/views/view-2.php';
                break;
            default:
                include $dir . '/views/view-1.php';
        }
    }
}
