<?php

namespace ElementHelper\Widget;

use \Elementor\Controls_Manager;
use \Elementor\Core\Schemes\Typography;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;

defined( 'ABSPATH' ) || die();

class Tx_Pricing_Box extends Element_El_Widget {

    /**
     * Get widget name.
     *
     * Retrieve Element Helper widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'tx_pricing_box';
    }

    /**
     * Get widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title() {
        return __( 'TX Pricing Box', 'future-core' );
    }

    public function get_custom_help_url() {
        return 'http://elementor.themexriver.com/widgets/gradient-heading/';
    }

    /**
     * Get widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'elh-widget-icon eicon-t-letter';
    }

    public function get_keywords() {
        return ['pricing', 'telnet', 'telnet pricing', 'price'];
    }

    public function elh_element_animations() {
        return [
            'none' => __( 'None', 'future-core' ),
            'fadeIn' => __( 'Fade In', 'future-core' ),
            'fadeInUp' => __( 'Fade In Up', 'future-core' ),
            'fadeInDown' => __( 'Fade In Down', 'future-core' ),
            'fadeInLeft' => __( 'Fade In Left', 'future-core' ),
            'fadeInRight' => __( 'Fade In Right', 'future-core' ),
            'fadeInUpBig' => __( 'Fade In Up Big', 'future-core' ),
            'fadeInDownBig' => __( 'Fade In Down Big', 'future-core' ),
            'fadeInLeftBig' => __( 'Fade In Left Big', 'future-core' ),
            'fadeInRightBig' => __( 'Fade In Right Big', 'future-core' ),
            'bounceIn' => __( 'Bounce In', 'future-core' ),
            'bounceInUp' => __( 'Bounce In Up', 'future-core' ),
            'bounceInDown' => __( 'Bounce In Down', 'future-core' ),
            'bounceInLeft' => __( 'Bounce In Left', 'future-core' ),
            'bounceInRight' => __( 'Bounce In Right', 'future-core' ),
            'rotateIn' => __( 'Rotate In', 'future-core' ),
            'rotateInUpLeft' => __( 'Rotate In Up Left', 'future-core' ),
            'rotateInDownLeft' => __( 'Rotate In Down Left', 'future-core' ),
            'rotateInUpRight' => __( 'Rotate In Up Right', 'future-core' ),
            'rotateInDownRight' => __( 'Rotate In Down Right', 'future-core' ),
            'lightSpeedIn' => __( 'Light Speed In', 'future-core' ),
            'rollIn' => __( 'Roll In', 'future-core' ),
            'zoomIn' => __( 'Zoom In', 'future-core' ),
            'zoomInUp' => __( 'Zoom In Up', 'future-core' ),
            'zoomInDown' => __( 'Zoom In Down', 'future-core' ),
            'zoomInLeft' => __( 'Zoom In Left', 'future-core' ),
            'zoomInRight' => __( 'Zoom In Right', 'future-core' ),
            'slideInUp' => __( 'Slide In Up', 'future-core' ),
            'slideInDown' => __( 'Slide In Down', 'future-core' ),
            'slideInLeft' => __( 'Slide In Left', 'future-core' ),
            'slideInRight' => __( 'Slide In Right', 'future-core' ),
        ];
    }

    protected function register_content_controls() {

        //Settings
        $this->start_controls_section(
            '_section_settings',
            [
                'label' => __( 'Settings', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'design_style',
            [
                'label'              => __( 'Design Style', 'future-core' ),
                'type'               => Controls_Manager::SELECT,
                'options'            => [
                    'style_1' => __( 'Style 1', 'future-core' ),
                ],
                'default'            => 'style_1',
                'frontend_available' => true,
                'style_transfer'     => true,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_title',
            [
                'label' => __( 'Header', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // badge text
        $this->add_control(
            'badge_text',
            [
                'label'       => __( 'Badge Text', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Badge Text', 'future-core' ),
                'label_block' => true,
            ]
        );

        // pricing header title
        $this->add_control(
            'pricing_title',
            [
                'label'       => __( 'Title', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Pricing Title', 'future-core' ),
                'label_block' => true,
            ]
        );

        // description
        $this->add_control(
            'pricing_description',
            [
                'label'       => __( 'Description', 'future-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'default'     => __( 'Pricing Description', 'future-core' ),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_package_feature',
            [
                'label' => __( 'Package Feature', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // package feature lists
        $repeater = new \Elementor\Repeater();

        // package feature icon
        $repeater->add_control(
            'package_feature_icon',
            [
                'label'       => __( 'Icon', 'future-core' ),
                'type'        => Controls_Manager::ICONS,
                'default'     => [
                    'value'   => 'fas fa-check',
                    'library' => 'solid',
                ],
                'label_block' => true,
            ]
        );

        // package feature title
        $repeater->add_control(
            'package_feature_title',
            [
                'label'       => __( 'Title', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Feature Title', 'future-core' ),
                'label_block' => true,
            ]
        );

        // package feature lists
        $this->add_control(
            'package_feature_lists',
            [
                'label'       => __( 'Feature Lists', 'future-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'package_feature_title' => __( 'Feature Title', 'future-core' ),
                    ],
                    [
                        'package_feature_title' => __( 'Feature Title', 'future-core' ),
                    ],
                    [
                        'package_feature_title' => __( 'Feature Title', 'future-core' ),
                    ],
                ],
                'title_field' => '{{{ package_feature_title }}}',
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            '_section_price',
            [
                'label' => __( 'Price', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'currency',
            [
                'label' => __('Currency', 'future-core'),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    '' => __('None', 'future-core'),
                    'baht' => '&#3647; ' . _x('Baht', 'Currency Symbol', 'future-core'),
                    'bdt' => '&#2547; ' . _x('BD Taka', 'Currency Symbol', 'future-core'),
                    'dollar' => '&#36; ' . _x('Dollar', 'Currency Symbol', 'future-core'),
                    'euro' => '&#128; ' . _x('Euro', 'Currency Symbol', 'future-core'),
                    'franc' => '&#8355; ' . _x('Franc', 'Currency Symbol', 'future-core'),
                    'guilder' => '&fnof; ' . _x('Guilder', 'Currency Symbol', 'future-core'),
                    'krona' => 'kr ' . _x('Krona', 'Currency Symbol', 'future-core'),
                    'lira' => '&#8356; ' . _x('Lira', 'Currency Symbol', 'future-core'),
                    'peseta' => '&#8359 ' . _x('Peseta', 'Currency Symbol', 'future-core'),
                    'peso' => '&#8369; ' . _x('Peso', 'Currency Symbol', 'future-core'),
                    'pound' => '&#163; ' . _x('Pound Sterling', 'Currency Symbol', 'future-core'),
                    'real' => 'R$ ' . _x('Real', 'Currency Symbol', 'future-core'),
                    'ruble' => '&#8381; ' . _x('Ruble', 'Currency Symbol', 'future-core'),
                    'rupee' => '&#8360; ' . _x('Rupee', 'Currency Symbol', 'future-core'),
                    'indian_rupee' => '&#8377; ' . _x('Rupee (Indian)', 'Currency Symbol', 'future-core'),
                    'shekel' => '&#8362; ' . _x('Shekel', 'Currency Symbol', 'future-core'),
                    'won' => '&#8361; ' . _x('Won', 'Currency Symbol', 'future-core'),
                    'yen' => '&#165; ' . _x('Yen/Yuan', 'Currency Symbol', 'future-core'),
                    'custom' => __('Custom', 'future-core'),
                ],
                'default' => 'dollar',
            ]
        );

        $this->add_control(
            'currency_custom',
            [
                'label' => __('Custom Symbol', 'future-core'),
                'type' => Controls_Manager::TEXT,
                'condition' => [
                    'currency' => 'custom',
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        // PRICE
        $this->add_control(
            'price',
            [
                'label' => __('Price', 'future-core'),
                'type' => Controls_Manager::TEXT,
                'default' => '9.99',
                'dynamic' => [
                    'active' => true
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_button',
            [
                'label' => __( 'Button', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // button text
        $this->add_control(
            'button_text',
            [
                'label'       => __( 'Text', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Button Text', 'future-core' ),
                'label_block' => true,
            ]
        );

        // button icon
        $this->add_control(
            'button_icon',
            [
                'label'       => __( 'Icon', 'future-core' ),
                'type'        => Controls_Manager::ICONS,
                'default'     => [
                    'value'   => 'fas fa-arrow-right',
                    'library' => 'solid',
                ],
                'label_block' => true,
            ]
        );

        // button link
        $this->add_control(
            'button_link',
            [
                'label'       => __( 'Link', 'future-core' ),
                'type'        => Controls_Manager::URL,
                'default'     => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

    }

    protected function register_style_controls() {

    }

    private static function get_currency_symbol($symbol_name)
    {
        $symbols = [
            'baht' => '&#3647;',
            'bdt' => '&#2547;',
            'dollar' => '&#36;',
            'euro' => '&#128;',
            'franc' => '&#8355;',
            'guilder' => '&fnof;',
            'indian_rupee' => '&#8377;',
            'pound' => '&#163;',
            'peso' => '&#8369;',
            'peseta' => '&#8359',
            'lira' => '&#8356;',
            'ruble' => '&#8381;',
            'shekel' => '&#8362;',
            'rupee' => '&#8360;',
            'real' => 'R$',
            'krona' => 'kr',
            'won' => '&#8361;',
            'yen' => '&#165;',
        ];

        return isset($symbols[$symbol_name]) ? $symbols[$symbol_name] : '';
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $dir = dirname( __FILE__ );

        if ($settings['currency'] === 'custom') {
            $currency = $settings['currency_custom'];
        } else {
            $currency = self::get_currency_symbol($settings['currency']);
        }

        $style = !empty($settings['design_style']) ? $settings['design_style'] : 'style_1';

        switch ($style) {
            case 'style_2':
                include $dir . '/views/view-2.php';
                break;
            default:
                include $dir . '/views/view-1.php';
        }
    }
}
