<?php

namespace ElementHelper\Widget;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
use \Elementor\Core\Schemes\Typography;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;


defined( 'ABSPATH' ) || die();

class Tx_Pricing_Tab extends Element_El_Widget {

    /**
     * Get widget name.
     *
     * Retrieve Future Core widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'tx_pricing_tab';
    }

    /**
     * Get widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title() {
        return __( 'TX Pricing Tab', 'future-core' );
    }

    public function get_custom_help_url() {
        return 'http://elementor.themexriver.com/widgets/gradient-heading/';
    }

    /**
     * Get widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'elh-widget-icon eicon-t-letter';
    }

    public function get_keywords() {
        return ['price', 'tab'];
    }

    protected function register_content_controls() {

        //Settings
        $this->start_controls_section(
            '_section_design_settings',
            [
                'label' => __( 'DESIGN STYLE', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'design_style',
            [
                'label'              => __( 'Design Style', 'future-core' ),
                'type'               => Controls_Manager::SELECT,
                'options'            => [
                    'style_1' => __( 'Style 1', 'future-core' ),
                    'style_2' => __( 'Style 2', 'future-core' ),
                ],
                'default'            => 'style_1',
                'frontend_available' => true,
                'style_transfer'     => true,
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            '_section_pricing_tab',
            [
                'label' => __( 'Pricing Tab', 'future-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        // save_text
        $this->add_control(
            'save_text',
            [
                'label'       => __( 'Save Text', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Save 20%', 'future-core' ),
                'label_block' => true,
                'condition' => [
                    'design_style' => 'style_1',
                ],
            ]
        );

        // repeater
        $repeater = new Repeater();

        // design style
        $repeater->add_control(
            'design_style',
            [
                'label'              => __( 'Design Style', 'future-core' ),
                'type'               => Controls_Manager::SELECT,
                'options'            => [
                    'style_1' => __( 'Style 1', 'future-core' ),
                    'style_2' => __( 'Style 2', 'future-core' ),
                ],
                'default'            => 'style_1',
                'frontend_available' => true,
                'style_transfer'     => true,
            ]
        );

        // is_active
        $repeater->add_control(
            'is_active',
            [
                'label'        => __( 'Active', 'future-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Show', 'future-core' ),
                'label_off'    => __( 'Hide', 'future-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        // tab_title
        $repeater->add_control(
            'tab_title',
            [
                'label'       => __( 'Tab Title', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Tab Title', 'future-core' ),
                'placeholder' => __( 'Type your title here', 'future-core' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'template',
            [
                'label' => __('Section Template', 'future-core'),
                'placeholder' => __('Select a section template for as tab content', 'future-core'),
                'description' => sprintf(__('Wondering what is section template or need to create one? Please click %1$shere%2$s ', 'future-core'),
                    '<a target="_blank" href="' . esc_url(admin_url('/edit.php?post_type=elementor_library&tabs_group=library&elementor_library_type=section')) . '">',
                    '</a>'
                ),
                'type' => Controls_Manager::SELECT2,
                'options' => get_elementor_templates(),
                'condition' => [
                    'design_style' => 'style_1',
                ],
            ]
        );

        // price image
        $repeater->add_control(
            'price_image',
            [
                'label'       => __( 'Price Image', 'future-core' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
                'condition' => [
                    'design_style' => 'style_2',
                ],
            ]
        );

        $repeater->add_control(
            'currency',
            [
                'label' => __('Currency', 'future-core'),
                'type' => Controls_Manager::SELECT,
                'label_block' => false,
                'options' => [
                    '' => __('None', 'future-core'),
                    'baht' => '&#3647; ' . _x('Baht', 'Currency Symbol', 'future-core'),
                    'bdt' => '&#2547; ' . _x('BD Taka', 'Currency Symbol', 'future-core'),
                    'dollar' => '&#36; ' . _x('Dollar', 'Currency Symbol', 'future-core'),
                    'euro' => '&#128; ' . _x('Euro', 'Currency Symbol', 'future-core'),
                    'franc' => '&#8355; ' . _x('Franc', 'Currency Symbol', 'future-core'),
                    'guilder' => '&fnof; ' . _x('Guilder', 'Currency Symbol', 'future-core'),
                    'krona' => 'kr ' . _x('Krona', 'Currency Symbol', 'future-core'),
                    'lira' => '&#8356; ' . _x('Lira', 'Currency Symbol', 'future-core'),
                    'peseta' => '&#8359 ' . _x('Peseta', 'Currency Symbol', 'future-core'),
                    'peso' => '&#8369; ' . _x('Peso', 'Currency Symbol', 'future-core'),
                    'pound' => '&#163; ' . _x('Pound Sterling', 'Currency Symbol', 'future-core'),
                    'real' => 'R$ ' . _x('Real', 'Currency Symbol', 'future-core'),
                    'ruble' => '&#8381; ' . _x('Ruble', 'Currency Symbol', 'future-core'),
                    'rupee' => '&#8360; ' . _x('Rupee', 'Currency Symbol', 'future-core'),
                    'indian_rupee' => '&#8377; ' . _x('Rupee (Indian)', 'Currency Symbol', 'future-core'),
                    'shekel' => '&#8362; ' . _x('Shekel', 'Currency Symbol', 'future-core'),
                    'won' => '&#8361; ' . _x('Won', 'Currency Symbol', 'future-core'),
                    'yen' => '&#165; ' . _x('Yen/Yuan', 'Currency Symbol', 'future-core'),
                    'custom' => __('Custom', 'future-core'),
                ],
                'default' => 'dollar',
            ]
        );

        $repeater->add_control(
            'currency_custom',
            [
                'label' => __('Custom Symbol', 'future-core'),
                'type' => Controls_Manager::TEXT,
                'condition' => [
                    'currency' => 'custom',
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        // PRICE
        $repeater->add_control(
            'price',
            [
                'label' => __('Price', 'future-core'),
                'type' => Controls_Manager::TEXT,
                'default' => '9.99',
                'dynamic' => [
                    'active' => true
                ]
            ]
        );

        $repeater->add_control(
            'pricing_title',
            [
                'label'       => __( 'Title', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Pricing Title', 'future-core' ),
                'label_block' => true,
                'condition' => [
                    'design_style' => 'style_2',
                ],
            ]
        );

        // description
        $repeater->add_control(
            'pricing_description',
            [
                'label'       => __( 'Description', 'future-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'default'     => __( 'Pricing Description', 'future-core' ),
                'label_block' => true,
                'condition' => [
                    'design_style' => 'style_2',
                ],
            ]
        );

        // package_feature_icon
        $repeater->add_control(
            'package_feature_icon',
            [
                'label'       => __( 'Package Feature Icon', 'future-core' ),
                'type'        => Controls_Manager::ICONS,
                'label_block' => true,
                'condition' => [
                    'design_style' => 'style_2',
                ],
            ]
        );

        $repeater->add_control(
            'package_feature_lists',
            [
                'label'       => __( 'Feature Lists', 'future-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'default'     => __( 'Feature Lists', 'future-core' ),
                'label_block' => true,
                'condition' => [
                    'design_style' => 'style_2',
                ],
            ]
        );

        // button text
        $repeater->add_control(
            'button_text',
            [
                'label'       => __( 'Text', 'future-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Button Text', 'future-core' ),
                'label_block' => true,
                'condition' => [
                    'design_style' => 'style_2',
                ],
            ]
        );

        // button icon
        $repeater->add_control(
            'button_icon',
            [
                'label'       => __( 'Icon', 'future-core' ),
                'type'        => Controls_Manager::ICONS,
                'default'     => [
                    'value'   => 'fas fa-arrow-right',
                    'library' => 'solid',
                ],
                'label_block' => true,
                'condition' => [
                    'design_style' => 'style_2',
                ],
            ]
        );

        // button link
        $repeater->add_control(
            'button_link',
            [
                'label'       => __( 'Link', 'future-core' ),
                'type'        => Controls_Manager::URL,
                'default'     => [
                    'url' => '#',
                ],
                'label_block' => true,
                'condition' => [
                    'design_style' => 'style_2',
                ],
            ]
        );


        // lists items
        $this->add_control(
            'pricingTab_lists',
            [
                'label'       => __( 'Pricing Tabs', 'future-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'tab_title' => __( 'Monthly', 'future-core' ),
                    ],
                    [
                        'tab_title' => __( 'Tab Title', 'future-core' ),
                    ],
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function register_style_controls() {

    }

    private static function get_currency_symbol($symbol_name)
    {
        $symbols = [
            'baht' => '&#3647;',
            'bdt' => '&#2547;',
            'dollar' => '&#36;',
            'euro' => '&#128;',
            'franc' => '&#8355;',
            'guilder' => '&fnof;',
            'indian_rupee' => '&#8377;',
            'pound' => '&#163;',
            'peso' => '&#8369;',
            'peseta' => '&#8359',
            'lira' => '&#8356;',
            'ruble' => '&#8381;',
            'shekel' => '&#8362;',
            'rupee' => '&#8360;',
            'real' => 'R$',
            'krona' => 'kr',
            'won' => '&#8361;',
            'yen' => '&#165;',
        ];

        return isset($symbols[$symbol_name]) ? $symbols[$symbol_name] : '';
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $dir = dirname( __FILE__ );

        $style = !empty($settings['design_style']) ? $settings['design_style'] : 'style_1';

        switch ($style) {
            case 'style_2':
                include $dir . '/views/view-2.php';
                break;
            default:
                include $dir . '/views/view-1.php';
        }
    }
}
